Index: src/mips/code-stubs-mips.cc |
diff --git a/src/mips/code-stubs-mips.cc b/src/mips/code-stubs-mips.cc |
index 72677799775179b518023b214d5a723adf1ae26d..c93c4d792022d4cb94c792d7f9bb34ed9f2acc4c 100644 |
--- a/src/mips/code-stubs-mips.cc |
+++ b/src/mips/code-stubs-mips.cc |
@@ -5784,10 +5784,10 @@ void StringHelper::GenerateTwoCharacterSymbolTableProbe(MacroAssembler* masm, |
__ Branch(&is_string, ne, scratch, Operand(ODDBALL_TYPE)); |
__ Branch(not_found, eq, undefined, Operand(candidate)); |
// Must be null (deleted entry). |
if (FLAG_debug_code) { |
- __ LoadRoot(scratch, Heap::kNullValueRootIndex); |
- __ Assert(eq, "oddball in symbol table is not undefined or null", |
+ __ LoadRoot(scratch, Heap::kTheHoleValueRootIndex); |
+ __ Assert(eq, "oddball in symbol table is not undefined or the hole value", |
scratch, Operand(candidate)); |
} |
__ jmp(&next_probe[i]); |
@@ -5784,10 +5784,10 @@ void StringHelper::GenerateTwoCharacterSymbolTableProbe(MacroAssembler* masm, |
__ Branch(&is_string, ne, scratch, Operand(ODDBALL_TYPE)); |
__ Branch(not_found, eq, undefined, Operand(candidate)); |
- // Must be null (deleted entry). |
+ // Must be the hole value (deleted entry). |
if (FLAG_debug_code) { |